@@ -34,15 +34,14 @@
 #include <opm/common/utility/numeric/cmp.hpp>
 
 #include <algorithm>
-#include <chrono>
 #include <cmath>
 #include <filesystem>
 #include <fstream>
 #include <iomanip>
 #include <iostream>
 #include <set>
-#include <type_traits>
 #include <typeinfo>
+#include <unordered_set>
 #include <vector>
 
 // helper macro to handle error throws or not
@@ -263,7 +262,7 @@ void ECLRegressionTest::printDeviationReport()
 
 void ECLRegressionTest::compareKeywords(const std::vector<std::string> &keywords1, const std::vector<std::string> &keywords2, const std::string &reference) {
 
-    if (!acceptExtraKeywords) {
+    if (!(acceptExtraKeywords or acceptExtraKeywordsBoth)) {
         if (keywords1 != keywords2) {
             std::cout << "not same keywords in " << reference << std::endl;
 
@@ -276,9 +275,11 @@ void ECLRegressionTest::compareKeywords(const std::vector<std::string> &keywords
                       "\nKeywords not identical in " + reference);
         }
     } else {
+        int extraKeywordsFirstFile = 0;
         for (auto& keyword : keywords1) {
             auto it1 = std::find(keywords2.begin(), keywords2.end(), keyword);
             if (it1 == keywords2.end()) {
+                extraKeywordsFirstFile++;
                 std::cout << "Keyword " << keyword << " missing in second file " << std::endl;
 
                 if (keywords1.size() > 50) {
@@ -286,22 +287,28 @@ void ECLRegressionTest::compareKeywords(const std::vector<std::string> &keywords
                 } else {
                     printComparisonForKeywordLists(keywords1, keywords2);
                 }
-
-                OPM_THROW(std::runtime_error,
-                          "\nKeyword " + keyword + " missing in second file ");
+                if (!acceptExtraKeywordsBoth) {
+                    OPM_THROW(std::runtime_error,
+                              "\nKeyword " + keyword + " missing in second file ");
+                }
             }
         }
 
-        if (keywords2.size() > keywords1.size()) {
+        if (keywords2.size() > keywords1.size() - extraKeywordsFirstFile) {
             std::cout << "\nExtra keywords ("
-                      << std::to_string(keywords2.size() - keywords1.size())
+                      << std::to_string(keywords2.size() - keywords1.size() + extraKeywordsFirstFile)
                       << ") accepted in second file " << std::endl;
         }
+        if (extraKeywordsFirstFile > 0) {
+            std::cout << "\nExtra keywords ("
+                      << extraKeywordsFirstFile
+                      << ") accepted in first file " << std::endl;
+        }
     }
 }
 
 
-void ECLRegressionTest::checkSpesificKeyword(std::vector<std::string>& keywords1,
+void ECLRegressionTest::checkSpecificKeyword(std::vector<std::string>& keywords1,
                                              std::vector<std::string>& keywords2,
                                              std::vector<eclArrType>& arrayType1,
                                              std::vector<eclArrType>& arrayType2,
@@ -319,10 +326,9 @@ void ECLRegressionTest::checkSpesificKeyword(std::vector<std::string>& keywords1
         OPM_THROW(std::runtime_error, "\n" + msg);
     }
 
-    eclArrType arrType;
     if (search1 != keywords1.end()) {
         int ind = std::distance(keywords1.begin(), search1);
-        arrType = arrayType1[ind];
+        const eclArrType arrType = arrayType1[ind];
 
         if (search2 == keywords2.end()) {
             const std::string msg =
@@ -604,8 +610,6 @@ void ECLRegressionTest::results_init()
         init1.loadData();
         init2.loadData();
 
-        std::string reference = "Init file";
-
         auto arrayList1 = init1.getList();
         auto arrayList2 = init2.getList();
 
@@ -629,6 +633,7 @@ void ECLRegressionTest::results_init()
             printComparisonForKeywordLists(keywords1,keywords2, arrayType1, arrayType2);
         } else {
             std::cout << "\nComparing init files \n" << std::endl;
+            std::string reference = "Init file";
 
             if (specificKeyword.empty()) {
                 if (keywords1.size() == keywords2.size() && keywords1 != keywords2) {
@@ -653,11 +658,14 @@ void ECLRegressionTest::results_init()
                 } else
                     compareKeywords(keywords1, keywords2, reference);
             } else {
-                checkSpesificKeyword(keywords1, keywords2, arrayType1, arrayType2, reference);
+                checkSpecificKeyword(keywords1, keywords2, arrayType1, arrayType2, reference);
             }
 
             for (size_t i = 0; i < keywords1.size(); i++) {
                 auto it1 = std::find(keywords2.begin(), keywords2.end(), keywords1[i]);
+                if (it1 == keywords2.end() and acceptExtraKeywordsBoth) {
+                    continue;
+                }
                 int ind2 = std::distance(keywords2.begin(),it1);
 
                 if (arrayType1[i] != arrayType2[ind2]) {
@@ -782,15 +790,15 @@ void ECLRegressionTest::results_rst()
             std::vector<std::string> seqnStrList1;
             std::vector<std::string> seqnStrList2;
 
-            for (auto& val : seqnums1) {
-                seqnStrList1.push_back(std::to_string(val));
-            }
+            std::transform(seqnums1.begin(), seqnums1.end(),
+                           std::back_inserter(seqnStrList1),
+                           [](const auto& val) { return std::to_string(val); });
+
+            std::transform(seqnums2.begin(), seqnums2.end(),
+                           std::back_inserter(seqnStrList2),
+                           [](const auto& val) { return std::to_string(val); });
 
-            for (auto& val : seqnums2) {
-                seqnStrList2.push_back(std::to_string(val));
-            }
             std::cout << "\nrestart sequences " << std::endl;
-
             printComparisonForKeywordLists(seqnStrList1, seqnStrList2);
             OPM_THROW(std::runtime_error, "\nRestart files not having the same report steps: ");
         }
@@ -831,6 +839,8 @@ void ECLRegressionTest::results_rst()
                         auto search2 = std::find(keywords2.begin(), keywords2.end(), keywords1[i]);
                         if (search2 != keywords2.end()) {
                             keywords.push_back(keywords1[i]);
+                        } else if (acceptExtraKeywordsBoth) {
+                            continue;
                         }
                     }
                 }
@@ -848,17 +858,17 @@ void ECLRegressionTest::results_rst()
                 if (specificKeyword.empty()) {
                     compareKeywords(keywords1, keywords2, reference);
                 } else {
-                    checkSpesificKeyword(keywords1, keywords2, arrayType1, arrayType2, reference);
+                    checkSpecificKeyword(keywords1, keywords2, arrayType1, arrayType2, reference);
                 }
 
-                std::unordered_set<std::string> keywords = {"IGRP"};
-
-
                 for (size_t i = 0; i < keywords1.size(); i++) {
                     //if (keywords.count(keywords1[i]) == 0)
                     //    continue;
 
                     auto it1 = std::find(keywords2.begin(), keywords2.end(), keywords1[i]);
+                    if (it1 == keywords2.end() and acceptExtraKeywordsBoth) {
+                        continue;
+                    }
                     int ind2 = std::distance(keywords2.begin(), it1);
 
                     if (arrayType1[i] != arrayType2[ind2]) {
@@ -985,6 +995,8 @@ void ECLRegressionTest::results_smry()
                 auto search2 = std::find(keywords2.begin(), keywords2.end(), kw);
                 if (search2 != keywords2.end()) {
                     keywords.push_back(kw);
+                } else if (acceptExtraKeywordsBoth) {
+                    continue;
                 }
             }
 
@@ -1006,25 +1018,30 @@ void ECLRegressionTest::results_smry()
             if (specificKeyword.empty()) {
                 compareKeywords(keywords1, keywords2, reference);
             } else {
-                checkSpesificKeyword(keywords1, keywords2, arrayType1, arrayType2, reference);
+                checkSpecificKeyword(keywords1, keywords2, arrayType1, arrayType2, reference);
             }
 
+            // Remove blacklisted keywords
             std::vector<std::string> blackListed;
-
-            for (std::vector<std::string>::iterator keywit = keywords1.begin(); keywit != keywords1.end(); ++keywit) {
-                auto it = std::find(keywordsBlackList.begin(), keywordsBlackList.end(), *keywit );
-
-                if (it != keywordsBlackList.end()){
-                    blackListed.push_back(*keywit);
-                    keywit = keywords1.erase(keywit);
-                    if (keywit != keywords1.end())
-                      --keywit;
-                }
-             }
+            keywords1.erase(std::remove_if(keywords1.begin(), keywords1.end(),
+                                           [&blacklist = keywordsBlackList, &blackListed](const auto& kw)
+                                           {
+                                               const auto it =
+                                                  std::find(blacklist.begin(), blacklist.end(), kw);
+                                               if (it != blacklist.end()) {
+                                                   blackListed.push_back(kw);
+                                               }
+                                               return it != blacklist.end();
+                                           }), keywords1.end());
 
             std::cout << "\nChecking " << keywords1.size() << "  vectors  ... ";
 
             for (size_t i = 0; i < keywords1.size(); i++) {
+                auto it1 = std::find(keywords2.begin(), keywords2.end(), keywords1[i]);
+                if (it1 == keywords2.end() and acceptExtraKeywordsBoth) {
+                    std::cout << "\nSkipping comparison for kw " << keywords1[i];
+                    continue;
+                }
 
                 std::vector<float> vect1;
                 std::vector<float> vect2;
@@ -1176,7 +1193,7 @@ void ECLRegressionTest::results_rft()
                 if (specificKeyword.empty()) {
                     compareKeywords(keywords1, keywords2, reference);
                 } else {
-                    checkSpesificKeyword(keywords1, keywords2, arrayType1, arrayType2, reference);
+                    checkSpecificKeyword(keywords1, keywords2, arrayType1, arrayType2, reference);
                 }
 
                 for (auto& array : vectList1 ) {
@@ -1252,7 +1269,7 @@ void ECLRegressionTest::printComparisonForKeywordLists(const std::vector<std::st
         commonList.insert(key);
     }
 
-    for (auto& key : commonList) {
+    for (const auto& key : commonList) {
         if (key.size() > maxLen) {
             maxLen = key.size();
         }
@@ -1341,7 +1358,7 @@ void ECLRegressionTest::printComparisonForKeywordLists(const std::vector<std::st
         commonList.insert(key);
     }
 
-    for (auto& key : commonList) {
+    for (const auto& key : commonList) {
         if (key.size() > maxLen) {
             maxLen = key.size();
         }
