@@ -30,19 +30,18 @@
 #include <opm/io/eclipse/ESmry.hpp>
 #include <opm/io/eclipse/EclOutput.hpp>
 
-#include <iomanip>
 #include "tests/WorkArea.hpp"
 
 using Opm::EclIO::EGrid;
 using Opm::EclIO::ESmry;
 using Opm::EclIO::EclOutput;
 
-void makeEgridFile(const std::string &fileName, const std::vector<float> &coord,
-                   const std::vector<float> &zcorn, const std::vector<int> &gridhead,
-		               const std::vector<int> &filehead,
-                   const std::vector<std::string> &gridunits,
-                   const std::vector<int> actnum, const std::vector<int> &nnc1,
-                   const std::vector<int> &nnc2)
+void makeEgridFile(const std::string& fileName, const std::vector<float>& coord,
+                   const std::vector<float>& zcorn, const std::vector<int>& gridhead,
+                   const std::vector<int>& filehead,
+                   const std::vector<std::string>& gridunits,
+                   const std::vector<int>& actnum, const std::vector<int>& nnc1,
+                   const std::vector<int>& nnc2)
 {
     EclOutput eclTest(fileName, false);
 
@@ -213,8 +212,6 @@ void makeSmryFile(const std::string &fileName,
 
     std::vector<int> seqhdr = {0,4,5,6,7,8,9};
 
-    std::vector<int> seqhdrValue = {-957426774};
-
     dimens[0] = params[0].size();
 
     EclOutput eclSmspecTest(fileName, false);
@@ -325,7 +322,6 @@ BOOST_AUTO_TEST_CASE(gridCompare) {
     // base:  identical grids
 
     std::vector<std::string> gridunits= {"METRES", ""};
-    std::vector<std::string> gdorient= {"INC", "INC", "INC", "DOWN", "RIGHT"};
 
     makeEgridFile("TMP1.EGRID",coord, zcorn, gridhead, filehead, gridunits, actnum, nnc1, nnc2);
     makeEgridFile("TMP2.EGRID",coord, zcorn, gridhead, filehead, gridunits, actnum, nnc1, nnc2);
@@ -447,7 +443,6 @@ BOOST_AUTO_TEST_CASE(results_init_1) {
 
     std::vector<float> permx1(12,1000.0);
     std::vector<float> porv1(12,1000.0);
-    std::vector<float> poro1(12,0.25);
     std::vector<int> fipnum1(12,1);
 
     std::vector<float> permx2(12,1000.0);
@@ -501,17 +496,17 @@ BOOST_AUTO_TEST_CASE(results_init_1) {
 
     // check with specific kewyword PORV, found in both cases and should be ok
     test1a.setAcceptExtraKeywords(false);
-    test1a.compareSpesificKeyword("PORV");
+    test1a.compareSpecificKeyword("PORV");
 
     test1a.results_init();
 
     // check with specific kewyword PORO, found in second case only, should throw exeption
-    test1a.compareSpesificKeyword("PORO");
+    test1a.compareSpecificKeyword("PORO");
 
     BOOST_CHECK_THROW(test1a.results_init(),std::runtime_error);
 
     // check with specific kewyword not found in any of the cases, should throw exeption
-    test1a.compareSpesificKeyword("XXXXX");
+    test1a.compareSpecificKeyword("XXXXX");
 
     BOOST_CHECK_THROW(test1a.results_init(),std::runtime_error);
 
@@ -527,12 +522,10 @@ BOOST_AUTO_TEST_CASE(results_init_2) {
 
     std::vector<float> permx1(12,1000.0);
     std::vector<float> porv1(12,1000.0);
-    std::vector<float> poro1(12,0.25);
     std::vector<int> fipnum1(12,1);
 
     std::vector<float> permx2(12,1000.0);
     std::vector<float> porv2(12,1000.0);
-    std::vector<float> poro2(12,0.25);
     std::vector<int> fipnum2(12,1);
 
     WorkArea work;
@@ -582,7 +575,7 @@ BOOST_AUTO_TEST_CASE(results_init_2) {
     // ---------------------------------------------------------------------------
     // compare specific keyword, should be ok sinze PORV not checked in this case
 
-    test2a.compareSpesificKeyword("PERMX");
+    test2a.compareSpecificKeyword("PERMX");
     test2a.doAnalysis(false);
     test2a.results_init();
 
@@ -725,19 +718,19 @@ BOOST_AUTO_TEST_CASE(results_unrst_1) {
 
     // checking for specific keyword PRESSURE, found in both cases
     test2a.setAcceptExtraKeywords(false);
-    test2a.compareSpesificKeyword("PRESSURE");
+    test2a.compareSpecificKeyword("PRESSURE");
 
     // test should be ok
     test2a.results_rst();
 
     // checking for specific keyword RS, only present in one of the cases
-    test2a.compareSpesificKeyword("RS");
+    test2a.compareSpecificKeyword("RS");
 
     // should fail
     BOOST_CHECK_THROW(test2a.results_rst(),std::runtime_error);
 
     // checking for specific keyword XXXX, not found in any of the cases
-    test2a.compareSpesificKeyword("XXXX");
+    test2a.compareSpecificKeyword("XXXX");
 
     // should fail
     BOOST_CHECK_THROW(test2a.results_rst(),std::runtime_error);
@@ -928,11 +921,11 @@ BOOST_AUTO_TEST_CASE(results_unrst_3) {
 
     // check specific keyword RS, should be OK
 
-    test2.compareSpesificKeyword("RS");
+    test2.compareSpecificKeyword("RS");
     test2.results_rst();
 
    // run full analysis, will not throw on first error
-    test2.compareSpesificKeyword("");
+    test2.compareSpecificKeyword("");
     test2.doAnalysis(true);
     test2.results_rst();
 
@@ -1023,15 +1016,15 @@ BOOST_AUTO_TEST_CASE(results_unsmry_1) {
     test2a.setAcceptExtraKeywords(false);
 
     // should be ok, since both cases have vector FOPT
-    test2a.compareSpesificKeyword("FOPT");
+    test2a.compareSpecificKeyword("FOPT");
     test2a.results_smry();
 
     // should fail since vector ROIP only found in first case
-    test2a.compareSpesificKeyword("ROIP:1");
+    test2a.compareSpecificKeyword("ROIP:1");
     BOOST_CHECK_THROW(test2a.results_smry(),std::runtime_error);
 
     // should fail since not found in any of the cases
-    test2a.compareSpesificKeyword("XXXXX");
+    test2a.compareSpecificKeyword("XXXXX");
     BOOST_CHECK_THROW(test2a.results_smry(),std::runtime_error);
 }
 
@@ -1234,13 +1227,13 @@ BOOST_AUTO_TEST_CASE(results_rft_1) {
     // accept extra keyword to false, but check for specific keyword (PRESSSURE)
 
     test1b.setAcceptExtraKeywords(false);
-    test1b.compareSpesificKeyword("PRESSURE");
+    test1b.compareSpecificKeyword("PRESSURE");
 
     // should be ok since both cases have solution PRESSURE, only solution checked
     test1b.results_rft();
 
     // SGAS, only present in second case, should fail
-    test1b.compareSpesificKeyword("SGAS");
+    test1b.compareSpecificKeyword("SGAS");
 
     BOOST_CHECK_THROW(test1b.results_rft(),std::runtime_error);
 
